<h1 align="center">
  <b>cpymadtools</b>
</h1>


The `cpymadtools` package is a lightweigth pythonic wrapper around `cpymad`.


Link to [documentation].

## License

Copyright &copy; 2022 Felix Soubelet. [MIT License](LICENSE)

[documentation]: https://fsoubelet.github.io/cpymadtools/
